@@ -19,6 +19,11 @@ class EmailConfigurationAdmin(admin.ModelAdmin):
     list_display = ('Subject',
                     'Logo',
                     'Banner',
-                    'Log_path',
                     'Email_Content',
-                    'HTML_File',)
+                    'Signature',
+                    'Email_Us',
+                    'FAQ_URL',
+                    'Unsubscribe_Email_ID',
+                    'Log_path',
+                    'HTML_File',
+                    )
\ No newline at end of file
