@@ -14,12 +14,11 @@ logger = logging.getLogger('dict_config_logger')
 def send_log_email():
     """ function to send emails of log file to personas"""
 
-    # getting email id to send email to personas
-
+    # getting email id to send email
     email_data = ReceiverEmailConfiguration.objects.values_list(
-        'email_address',
-        flat=True)
+        'email_address', flat=True)
     email = list(email_data)
+
     # Getting sender email id
     sender_email_configuration = SenderEmailConfiguration.objects.first()
     sender = sender_email_configuration.sender_email_address
@@ -27,9 +26,7 @@ def send_log_email():
     email_configuration = EmailConfiguration.objects.values(
         'Subject', 'Logo', 'Banner', 'Email_Content', 'Signature', 'Email_Us',
         'FAQ_URL', 'Unsubscribe_Email_ID', 'Log_path', 'HTML_File').first()
-    # SUBJECT = email_configuration.SUBJECT
-    # HTML_File = email_configuration.HTML_File
-    # LOG_PATH = email_configuration.LOG_PATH
+
     send_notifications(email, sender, email_configuration)
 
 
