@@ -51,24 +51,25 @@ def send_notifications(email, sender, email_configuration):
     # Replace sender@example.com with your "From" address.
     # This address must be verified with Amazon SES.
     SENDER = sender
+
     # Replace recipient@example.com with a "To" address. If your account
     # is still in the sandbox, this address must be verified.
-
     RECIPIENT = email
+
+    # Getting path of email cover picture and logo picture
+    cover = '/' + email_configuration.get('Banner')
+    logger.info(cover)
+    logo = '/' + email_configuration.get('Logo')
+    logger.info(logo)
     # The subject line for the email.
     SUBJECT = email_configuration.get('Subject')
-    LOG_PATH = email_configuration.get('Log_path')
 
     # The full path to the file that will be attached to the email.
+    LOG_PATH = email_configuration.get('Log_path')
     ATTACHMENT = LOG_PATH
-    cover = settings.MEDIA_ROOT + '/' + email_configuration.get('Banner')
-    logger.info(cover)
-    logo = settings.MEDIA_ROOT + '/' + email_configuration.get('Logo')
-    logger.info(logo)
 
     # # The HTML body of the email.
     file_name = email_configuration.get('HTML_File')
-    logger.info(file_name)
     BODY_HTML = open('media/' + file_name).read().format(
         cover=cover, logo=logo,
         paragraph=email_configuration.get('Email_Content'),
